#
# spec file for package datovka
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           datovka
Version:        4.6.0
Release:        2.2
Summary:        Library to access Czech eGov system \"Datove schranky\"
License:        LGPL-2.0+
Group:          Development/Libraries/Python
Url:            https://labs.nic.cz/cs/nova-datovka.html
Source0:        https://secure.nic.cz/files/datove_schranky/%{version}/%{name}-%{version}-src.tar.xz
# PATCH-FIX-UPSTREAM: remove some issues with current .pro file
Patch0:         datovka-fix-pro.patch
BuildRequires:  libqt5-linguist
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.2.0
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Sql) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
BuildRequires:  pkgconfig(libisds)
Requires:       dejavu
Requires:       libqt5_sql_backend
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     %{name}-lang
# Included inside with different approach
Obsoletes:      python-dslib
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A library for accessing ISDS (Informační system datovych schranek/
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%{?lang_package}

%prep
%setup -q
%patch0
sed -i \
    -e 's:lrelease:lrelease-qt5:g' \
    %{name}.pro

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
lrelease-qt5 datovka.pro
%qmake5 PREFIX=%{_prefix} DISABLE_VERSION_CHECK_BY_DEFAULT=1
make %{?_smp_mflags}

%install
make install INSTALL_ROOT=%{buildroot}

# fix desktop file
sed -i \
    -e 's:Office;:Office;Network;Email;:g' \
    %{buildroot}%{_datadir}/applications/datovka.desktop
rm -rf %{buildroot}%{_datadir}/datovka/doc

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%{_bindir}/datovka
%{_datadir}/applications/datovka.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/datovka.appdata.xml
%dir %{_datadir}/datovka
%dir %{_datadir}/datovka/localisations/
%{_datadir}/datovka/localisations/datovka_cs.qm
%{_datadir}/datovka/localisations/datovka_en.qm
%{_datadir}/icons/hicolor/*

%changelog
* Sat May 14 2016 tchvatal@suse.com
- Version update to 4.6.0:
  * Added support for tags. These can be locally assigned to the messages.
  * Message information are shown in separate window when double-clicking the
    message in message list or when hitting the Return/Enter key.
  * When composing a message, the recipient can be added to the recipient list
    by double clicking it in the recently-used recipient list.
  * Information about personal delivery are shown in message description field.
  * Fixed problem where account entry has not been updated after message
    deletion.
  * Fixed encoding issue when exporting correspondence overview in HTML.
  * Fixed a bug causing the create message button not to activate when first
    account was created.
* Fri Apr  1 2016 mpluskal@suse.com
- Update to 4.5.3
  * Fixed problems with HOTP authorisation on Windows. There have
    been problems with the bundled libisds. MinGW does not handle
    POSIX extensions of printf formatting strings properly. Patch
    for libisds has been added.
  * Fixed a non-working PRAGMA statement when asking for a database
    integrity check.
  * The --version command-line argument now also prints the version
    of libraries which Datovka depends on.
  * Automatic background downloads didn't cause the deactivation of
    download buttons that could still be triggered. Triggering those
    buttons in this situation could cause the application to crash.
  * Adding new account caused the account tree to collapse. This has
    been fixed.
- Changes for 4.5.2
  * NLS of bundled libisds (OS X, Windows) has been disabled.
  * The logging of libisds actions has been restricted on Windows
    because there are discrepancies from standard-defined behaviour
    of some functions on Windows.
  * Improved behaviour when message download fails. The error
    dialogue is only shown when an explicit message download fails.
  * A message in the notification area appears when the download
    has been triggered by downloading message list. This should
    reduce the amount of error dialogues generated.
  * Improved behaviour when downloading messages on accounts with
    restricted privileges. Received messages are not automatically
    downloaded when the user has no privileges to do that.
- Changes for 4.5.1
  * Fixed bug in action logging causing the application to crash
    occasionally.
  * Fixed bug where message line was not deleted when deleting from
    ISDS failed.
  * New account model internals.
- Build with optflags
- Use macros for desktop file and icon handling
* Tue Feb 16 2016 tchvatal@suse.com
- Version update to 4.5.0:
  * various backend updates
  * various bugs fixed
  * qt 5.3 required now
- Rebase patch:
  * datovka-fix-pro.patch
* Tue Jan  5 2016 tchvatal@suse.com
- Version update to 4.4.3:
  * Various bugfixes. See ChangeLog file
  * Fixed broken expired password swap
* Mon Oct 12 2015 tchvatal@suse.com
- Version update to 4.4.0:
  * Various bugfixes all around. See ChangeLog file
* Sat Sep  5 2015 tchvatal@suse.com
- Version bump 4.3.1:
  * Few small bugfixes see ChangeLog for details
- Refresh patch datovka-fix-pro.patch
* Wed Jun  3 2015 tchvatal@suse.com
- Version bump to 4.3.0:
  * No obvious changelog apart from mentioning bugfixes
* Tue Mar 31 2015 tchvatal@suse.com
- Version bump to 4.2.0:
  * Various bugfixes
  * Resending messages/etc
- Obsoleted patch:
  * 0001-no-check-new-versions.patch
* Tue Feb 24 2015 tchvatal@suse.com
- Version bump to 4.1.2:
  * Various bugfixes
- Add patch to not ask about new version availabilty:
  * 0001-no-check-new-versions.patch
- Refreshed patch:
  * datovka-fix-pro.patch
* Mon Feb  2 2015 tchvatal@suse.com
- Version bump to 4.1:
  * Complete rewrite under qt5
  * Should provide same usability, reffer to homepage for more info
- Various cleanups
- Add patch to fix building with respecting cflags/etc:
  * datovka-fix-pro.patch
* Mon Sep 15 2014 tchvatal@suse.com
- Version bump to 3.1:
  * Detect better file suffixes
  * work with sqlalchemy 0.9
- Cleanup with spec-cleaner
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jul 16 2013 tchvatal@suse.com
- Format spec file was run and it was not changelogged.
* Fri Jan 25 2013 tchvatal@suse.com
- Upstream moves the tarball all around, just not track it.
* Wed Jan 23 2013 tchvatal@suse.com
- Forgot to own datadir.
* Wed Jan 23 2013 tchvatal@suse.com
- Sort out desktop file for SLE.
* Wed Jan 23 2013 tchvatal@suse.com
- Fix various rpmlint warnings to make it happy.
* Wed Jan 23 2013 tchvatal@suse.com
- Add build_root and python stuff to theoretically build on sle.
* Wed Jan 23 2013 tchvatal@suse.com
- Add more runtime deps to be on safe side here.
* Mon Jan 21 2013 tchvatal@suse.com
- Fix download url as upstream decided to move it.
* Fri Jan 18 2013 tchvatal@suse.com
- Add py_requires macro.
* Mon Jan  7 2013 tchvatal@suse.com
- Version bump to 3.0.3.
* Thu Dec 20 2012 tchvatal@suse.com
- Version bump to 3.0.2. Raise dslib dep. Remove dejavu hack.
* Fri Nov 30 2012 tchvatal@suse.com
- Version bump to 2.1.1. Raise dslib dep.
* Thu Apr 26 2012 tchvatal@suse.com
- Bump to version 2.0.2. Depend on newer python-dslib.
* Wed Dec  7 2011 tchvatal@suse.com
- Remove _service, clean phase, add some docs
* Tue Dec  6 2011 tchvatal@suse.com
- Initial commit of datovka.
